# -*- coding: utf8 -*-
from __future__ import unicode_literals

import random

from driverng.protocol.astm import AstmProtocol
from driverng.utils import ACK, ENQ, EOT, STX, byte2log


class AstmAtrasProtocol(AstmProtocol):
    def recv_trames(self):
        """Reçoit une liste de trames (message) sur la connexion::

            <- <enq>
            -> <ack>
            <- DATA
            -> <ack>
            <- <eot>

        :return: False si erreur sinon la liste des messages reçus
        """

        # timeout non spécifié dans le protocole
        data = self.read(timeout=1)

        if not data or data[0] != ENQ:
            self.rtimeout = random.randint(10, 20)
            self.logger.info(
                "<enq> expected in %s: wait %ds", byte2log(data), self.rtimeout
            )
            return False

        self.write(ACK)

        trames = b""

        while True:
            # il faut faire un read avec un timeout 15
            # pour l'ensemble de la trame
            ctrl = self.read(timeout=15)
            if not ctrl:
                return False
            if ctrl[0] == EOT:
                break
            if ctrl[0] != STX:
                self.logger.warning("<stx> expexted in %s", byte2log(ctrl))
                return False
            data = self.readline(timeout=15)
            # La vérification du checksum ne fonctionne pas en réception
            self.write(ACK)
            trames += self.get_payload(data)

        messages = b"\n".join(trames.splitlines())
        return self.get_messages(messages.splitlines())
